@@ -30,7 +30,6 @@ CREATE OR REPLACE FUNCTION geometry(pcpatch)
 	$$
 	LANGUAGE 'sql';
 
-CREATE CAST (pcpatch AS geometry) WITH FUNCTION PC_EnvelopeGeometry(pcpatch);
 
 
 -----------------------------------------------------------------------------
@@ -43,7 +42,6 @@ CREATE OR REPLACE FUNCTION geometry(pcpoint)
 	$$
 	LANGUAGE 'sql';
 
-CREATE CAST (pcpoint AS geometry) WITH FUNCTION geometry(pcpoint);
 
 
 -----------------------------------------------------------------------------
@@ -77,5 +75,5 @@ CREATE OR REPLACE FUNCTION PC_BoundingDiagonalGeometry(pcpatch)
 -- Function returning the version number
 --
 CREATE OR REPLACE FUNCTION PC_PostGIS_Version()
-	RETURNS text AS $$ SELECT '1.2.4'::text $$
+	RETURNS text AS $$ SELECT '1.2.5'::text $$
 	LANGUAGE 'sql' IMMUTABLE STRICT;
